/******/ (() => { // webpackBootstrap
/******/ 	"use strict";
var __webpack_exports__ = {};
/*!*********************************************************************!*\
  !*** ./resources/assets/js/patient_admissions/patient_admission.js ***!
  \*********************************************************************/


$(document).ready(function () {
  var patientAdmissionsTable = '#patientAdmissionsTbl';
  var tbl = $(patientAdmissionsTable).DataTable({
    processing: true,
    serverSide: true,
    searchDelay: 500,
    'language': {
      'lengthMenu': 'Show _MENU_'
    },
    'order': [[10, 'desc']],
    ajax: {
      url: patientAdmissionsUrl,
      data: function data(_data) {
        _data.status = $('#filter_status').find('option:selected').val();
      }
    },
    columnDefs: [{
      'targets': [0],
      'width': '10%'
    }, {
      'targets': [9],
      'width': '8%',
      'orderable': false,
      'className': 'text-center text-nowrap'
    }, {
      'targets': [8],
      'width': '5%',
      'orderable': false
    }, {
      'targets': [10],
      'visible': false
    }, {
      targets: '_all',
      defaultContent: 'N/A',
      'className': 'text-start align-middle text-nowrap'
    }],
    columns: [{
      data: function data(row) {
        return '<a href="#" class="show-btn badge badge-light-info" data-id="' + row.id + '">' + row.patient_admission_id + '</a>';
      },
      name: 'patient_admission_id'
    }, {
      data: function data(row) {
        var showLink = patientUrl + '/' + row.patient.id;
        return "<div class=\"d-flex align-items-center\">\n                        <div class=\"symbol symbol-circle symbol-50px overflow-hidden me-3\">\n                        <a href=\"".concat(showLink, "\">\n                            <div class=\"\">\n                                <img src=\"").concat(row.patientImageUrl, "\" alt=\"\"\n                                     class=\"user-img\">\n                            </div>\n                        </a>\n                    </div>\n                    <div class=\"d-flex flex-column\">\n                        <a href=\"").concat(showLink, "\"\n                           class=\"mb-1\">").concat(row.patient.user.full_name, "</a>\n                        <span>").concat(row.patient.user.email, "</span>\n                    </div>\n                </div>");
      },
      name: 'patient.user.first_name'
    }, {
      data: function data(row) {
        if (userRole) {
          return row.doctor.user.full_name;
        }

        var showLink = doctorUrl + '/' + row.doctor.id;
        return "<div class=\"d-flex align-items-center\">\n                        <div class=\"symbol symbol-circle symbol-50px overflow-hidden me-3\">\n                        <a href=\"".concat(showLink, "\">\n                            <div>\n                                <img src=\"").concat(row.doctorImageUrl, "\" alt=\"\"\n                                     class=\"user-img\">\n                            </div>\n                        </a>\n                        </div>\n                        <div class=\"d-flex flex-column\">\n                            <a href=\"").concat(showLink, "\"\n                               class=\"mb-1\">").concat(row.doctor.user.full_name, "</a>\n                            <span>").concat(row.doctor.user.email, "</span>\n                        </div>\n                    </div>");
      },
      name: 'doctor.user.first_name'
    }, {
      data: function data(row) {
        return row;
      },
      render: function render(row) {
        if (row.admission_date === null) {
          return 'N/A';
        }

        return "<div class=\"badge badge-light\">\n                                <div class=\"mb-2\">".concat(moment(row.admission_date).format('LT'), "</div>\n                                <div>").concat(moment(row.admission_date).format('Do MMM, Y'), "</div>\n                            </div>");
      },
      name: 'admission_date'
    }, {
      data: function data(row) {
        return row;
      },
      render: function render(row) {
        if (row.discharge_date === null) {
          return 'N/A';
        }

        return "<div class=\"badge badge-light\">\n                                <div class=\"mb-2\">".concat(moment(row.discharge_date).format('LT'), "</div>\n                                <div>").concat(moment(row.discharge_date).format('Do MMM, Y'), "</div>\n                            </div>");
      },
      name: 'discharge_date'
    }, {
      data: function data(row) {
        if (isEmpty(row.package_id)) {
          return 'N/A';
        }

        var showLink = packageUrl + '/' + row["package"].id;
        return '<a href="' + showLink + '">' + row["package"].name + '</a>';
      },
      name: 'package.name'
    }, {
      data: function data(row) {
        if (isEmpty(row.insurance_id)) {
          return 'N/A';
        }

        var showLink = insuranceUrl + '/' + row.insurance.id;
        return '<a href="' + showLink + '">' + row.insurance.name + '</a>';
      },
      name: 'insurance.name'
    }, {
      data: function data(row) {
        return isEmpty(row.policy_no) ? 'N/A' : row.policy_no;
      },
      name: 'policy_no'
    }, {
      data: function data(row) {
        var checked = row.status == 0 ? '' : 'checked';
        var data = [{
          'id': row.id,
          'checked': checked
        }];
        return "<label class=\"form-check form-switch form-check-custom form-check-solid form-switch-sm\"><input name=\"status\" data-id=\"".concat(row.id, "\" class=\"form-check-input status\" type=\"checkbox\" value=\"1\" ").concat(checked, " /><span class=\"switch-slider\" data-checked=\"&#x2713;\" data-unchecked=\"&#x2715;\"></span></label>");
      },
      name: 'status'
    }, {
      data: function data(row) {
        var url = patientAdmissionsUrl + '/' + row.id;
        var data = [{
          'id': row.id,
          'url': url + '/edit',
          'viewUrl': url
        }];
        return prepareTemplateRender('.pageActionTemplate', data);
      },
      name: 'id'
    }, {
      data: 'created_at',
      name: 'created_at'
    }],
    'fnInitComplete': function fnInitComplete() {
      $('#filter_status').change(function () {
        $(patientAdmissionsTable).DataTable().ajax.reload(null, true);
      });
    }
  });
  handleSearchDatatable(tbl);
  $(document).on('click', '.delete-btn', function (event) {
    var id = $(event.currentTarget).data('id');
    deleteItem(patientAdmissionsUrl + '/' + id, patientAdmissionsTable, 'Patient Admission');
  });
  $(document).on('change', '.status', function (event) {
    var id = $(event.currentTarget).data('id');
    updateStatus(id);
  });
  $(document).on('click', '.show-btn', function (event) {
    var patientAdmissionId = $(event.currentTarget).attr('data-id');
    renderData(patientAdmissionId);
  });

  window.renderData = function (id) {
    $.ajax({
      url: route('patient-admissions.show.modal', id),
      type: 'GET',
      success: function success(result) {
        if (result.success) {
          $('#patient_name').text(result.data.patient.user.full_name);
          $('#doctor_name').text(result.data.doctor.user.full_name);
          $('#admission_id').text(result.data.patient_admission_id);
          $('#admission_date').text(result.data.admission_date);
          $('#discharge_date').text(result.data.discharge_date);
          $('#package').text(result.data["package"] ? result.data["package"].name : 'N/A');
          $('#insurance').text(result.data.insurance ? result.data.insurance.name : 'N/A');
          $('#admission_bed').text(result.data.bed ? result.data.bed.name : 'N/A');
          $('#policy_no').text(result.data.policy_no);
          $('#agent_name').text(result.data.agent_name);
          $('#guardian_name').text(result.data.guardian_name);
          $('#guardian_relation').text(result.data.guardian_relation);
          $('#guardian_contact').text(result.data.guardian_contact);
          $('#guardian_address').text(result.data.guardian_address);
          $('#patient_status').empty();

          if (result.data.status == 1) {
            $('#patient_status').append('<span class="badge badge-light-success">Active</span>');
          } else {
            $('#patient_status').append('<span class="badge badge-light-danger">Deactive</span>');
          }

          $('#created_on').text(moment(result.data.created_at).fromNow());
          $('#updated_on').text(moment(result.data.updated_at).fromNow());
          setValueOfEmptySpan();
          $('#showPatientAdmission').appendTo('body').modal('show');
        }
      },
      error: function error(result) {
        displayErrorMessage(result.responseJSON.message);
      }
    });
  };

  $(document).on('click', '#resetFilter', function () {
    $('#filter_status').val(2).trigger('change');
  });

  window.updateStatus = function (id) {
    $.ajax({
      url: patientAdmissionsUrl + '/' + +id + '/active-deactive',
      method: 'post',
      cache: false,
      success: function success(result) {
        if (result.success) {
          displaySuccessMessage(result.message);
          tbl.ajax.reload(null, false);
        }
      }
    });
  };
});
/******/ })()
;