/******/ (() => { // webpackBootstrap
/******/ 	"use strict";
var __webpack_exports__ = {};
/*!************************************************************!*\
  !*** ./resources/assets/js/patient_cases/patient_cases.js ***!
  \************************************************************/


$(document).ready(function () {
  var tableName = '#casesTbl';
  var tbl = $('#casesTbl').DataTable({
    processing: true,
    serverSide: true,
    searchDelay: 500,
    'language': {
      'lengthMenu': 'Show _MENU_'
    },
    'order': [[3, 'desc']],
    ajax: {
      url: casesUrl,
      data: function data(_data) {
        _data.status = $('#filter_status').find('option:selected').val();
      }
    },
    columnDefs: [{
      'targets': [0],
      'width': '10%'
    }, {
      'targets': [2],
      'width': '20%'
    }, {
      'targets': [5],
      'orderable': false,
      'width': '6%'
    }, {
      'targets': [6],
      'orderable': false,
      'className': 'text-center text-nowrap',
      'width': '8%'
    }, {
      'targets': [7, 8],
      'visible': false
    }, {
      targets: '_all',
      defaultContent: 'N/A',
      'className': 'text-start align-middle text-nowrap'
    }],
    columns: [{
      data: function data(row) {
        return '<a data-id="' + row.id + '" href="#" class="show-btn badge badge-light-info">' + row.case_id + '</a>';
      },
      name: 'case_id'
    }, {
      data: function data(row) {
        var showLink = patientUrl + '/' + row.patient.id;
        return "<div class=\"d-flex align-items-center\">\n                                <div class=\"symbol symbol-circle symbol-50px overflow-hidden me-3\">\n                                    <a href=\"".concat(showLink, "\">\n                                        <div>\n                                            <img src=\"").concat(row.patientImageUrl, "\" alt=\"\"\n                                                 class=\"user-img\">\n                                        </div>\n                                    </a>\n                                </div>\n                            <div class=\"d-flex flex-column\">\n                                <a href=\"").concat(showLink, "\" class=\"mb-1\">").concat(row.patient.user.full_name, "</a>\n                                <span>").concat(row.patient.user.email, "</span>\n                            </div>\n                    </div>");
      },
      name: 'patient.user.first_name'
    }, {
      data: function data(row) {
        if (userRole) {
          return row.doctor.user.full_name;
        }

        var showLink = doctorUrl + '/' + row.doctor.id;
        return "<div class=\"d-flex align-items-center\">\n                                <div class=\"symbol symbol-circle symbol-50px overflow-hidden me-3\">\n                                    <a href=\"".concat(showLink, "\">\n                                        <div>\n                                            <img src=\"").concat(row.doctorImageUrl, "\" alt=\"\"\n                                                 class=\"user-img\">\n                                        </div>\n                                    </a>\n                                </div>\n                            <div class=\"d-flex flex-column\">\n                                <a href=\"").concat(showLink, "\" class=\"mb-1\">").concat(row.doctor.user.full_name, "</a>\n                                <span>").concat(row.doctor.user.email, "</span>\n                            </div>\n                    </div>");
      },
      name: 'doctor.user.first_name'
    }, {
      data: function data(row) {
        return row;
      },
      render: function render(row) {
        if (row.date === null) {
          return '';
        }

        return "<div class=\"badge badge-light\">\n                                <div class=\"mb-2\">".concat(moment(row.date).format('LT'), "</div>\n                                <div>").concat(moment(row.date).format('Do MMM, Y'), "</div>\n                            </div>");
      },
      name: 'date'
    }, {
      data: function data(row) {
        return !isEmpty(row.fee) ? '<p class="cur-margin">' + getCurrentCurrencyClass() + ' ' + addCommas(row.fee) + '</p>' : 'N/A';
      },
      name: 'fee'
    }, {
      data: function data(row) {
        var checked = row.status == 0 ? '' : 'checked';
        return "<label class=\"form-check form-switch form-check-custom form-check-solid form-switch-sm\"><input name=\"status\" data-id=\"".concat(row.id, "\" class=\"form-check-input status\" type=\"checkbox\" value=\"1\" ").concat(checked, " /><span class=\"switch-slider\" data-checked=\"&#x2713;\" data-unchecked=\"&#x2715;\"></span></label>");
      },
      name: 'status'
    }, {
      data: function data(row) {
        var url = casesUrl + '/' + row.id;
        var data = [{
          'id': row.id,
          'url': url + '/edit'
        }];
        return prepareTemplateRender('.pageActionTemplate', data);
      },
      name: 'id'
    }, {
      data: 'patient.user.last_name',
      name: 'patient.user.last_name'
    }, {
      data: 'doctor.user.last_name',
      name: 'doctor.user.last_name'
    }],
    'fnInitComplete': function fnInitComplete() {
      $('#filter_status').change(function () {
        $(tableName).DataTable().ajax.reload(null, true);
      });
    }
  });
  handleSearchDatatable(tbl);
  $(document).on('click', '.delete-btn', function (event) {
    var caseId = $(event.currentTarget).data('id');
    deleteItem(casesUrl + '/' + caseId, '#casesTbl', 'Case');
  });
  $(document).on('click', '#resetFilter', function () {
    $('#filter_status').val(2).trigger('change');
  }); // status activation deactivation change event

  $(document).on('change', '.status', function (event) {
    var caseId = $(event.currentTarget).data('id');
    activeDeActiveStatus(caseId);
  }); // activate de-activate Status

  window.activeDeActiveStatus = function (id) {
    $.ajax({
      url: casesUrl + '/' + id + '/active-deactive',
      method: 'post',
      cache: false,
      success: function success(result) {
        if (result.success) {
          displaySuccessMessage(result.message);
          tbl.ajax.reload();
        }
      }
    });
  };

  $(document).on('click', '.show-btn', function (event) {
    var patientCaseId = $(event.currentTarget).attr('data-id');
    renderData(patientCaseId);
  });

  window.renderData = function (id) {
    $.ajax({
      url: route('patient_case.show.modal', id),
      type: 'GET',
      success: function success(result) {
        if (result.success) {
          $('#case_id').text(result.data.case_id);
          $('#patient_name').text(result.data.patient.user.full_name);
          $('#patient_phone').text(result.data.phone);
          $('#patient_doctor').text(result.data.doctor.user.full_name);
          $('#case_date').text(moment(result.data.date).format('Do MMM, Y h:mm A'));
          $('#case_fee').text(currentCurrency + ' ' + addCommas(result.data.fee));
          $('#description').text(result.data.description);
          $('#patientStatus').empty();

          if (result.data.status == 1) {
            $('#patientStatus').append('<span class="badge badge-light-success">Active</span>');
          } else {
            $('#patientStatus').append('<span class="badge badge-light-danger">Deactive</span>');
          }

          $('#created_on').text(moment(result.data.created_at).fromNow());
          $('#updated_on').text(moment(result.data.updated_at).fromNow());
          setValueOfEmptySpan();
          $('#showPatientCase').appendTo('body').modal('show');
        }
      },
      error: function error(result) {
        displayErrorMessage(result.responseJSON.message);
      }
    });
  };
});
/******/ })()
;