/******/ (() => { // webpackBootstrap
/******/ 	"use strict";
var __webpack_exports__ = {};
/*!*************************************************!*\
  !*** ./resources/assets/js/settings/setting.js ***!
  \*************************************************/


var tableName = '#modulesTbl';
var tbl = $(tableName).DataTable({
  processing: true,
  serverSide: true,
  searchDelay: 500,
  'language': {
    'lengthMenu': 'Show _MENU_'
  },
  'order': [[0, 'asc']],
  ajax: {
    url: moduleUrl,
    data: function data(_data) {
      _data.status = $('#filter_status').find('option:selected').val();
    }
  },
  columnDefs: [{
    'targets': [1],
    'className': 'text-center text-nowrap',
    'orderable': false,
    'width': '5%'
  }, {
    targets: '_all',
    defaultContent: 'N/A',
    'className': 'text-start align-middle text-nowrap'
  }],
  columns: [{
    data: 'name',
    name: 'name'
  }, {
    data: function data(row) {
      var checked = row.is_active == 0 ? '' : 'checked';
      var data = [{
        'id': row.id,
        'checked': checked
      }];
      return prepareTemplateRender('#moduleStatusTemplate', data);
    },
    name: 'is_active'
  }],
  'fnInitComplete': function fnInitComplete() {
    $('#filter_status').change(function () {
      $(tableName).DataTable().ajax.reload(null, true);
    });
  }
});

if (searchExist) {
  handleSearchDatatable(tbl);
}

$(document).ready(function () {
  $('#currencyType').select2({
    width: '100%'
  });
});
$(document).on('change', '#appLogo', function () {
  $('#validationErrorsBox').addClass('d-none');

  if (isValidLogo($(this), '#validationErrorsBox')) {
    displayLogo(this, '#previewImage');
  }
});
$('#facebookUrl').keyup(function () {
  this.value = this.value.toLowerCase();
});
$('#twitterUrl').keyup(function () {
  this.value = this.value.toLowerCase();
});
$('#instagramUrl').keyup(function () {
  this.value = this.value.toLowerCase();
});
$('#linkedInUrl').keyup(function () {
  this.value = this.value.toLowerCase();
});
$(document).on('submit', '#createSetting', function (event) {
  event.preventDefault();

  if ($('#error-msg').text() !== '') {
    $('#phoneNumber').focus();
    return false;
  }

  var facebookUrl = $('#facebookUrl').val();
  var twitterUrl = $('#twitterUrl').val();
  var instagramUrl = $('#instagramUrl').val();
  var linkedInUrl = $('#linkedInUrl').val();
  var facebookExp = new RegExp(/^(https?:\/\/)?((m{1}\.)?)?((w{2,3}\.)?)facebook.[a-z]{2,3}\/?.*/i);
  var twitterExp = new RegExp(/^(https?:\/\/)?((m{1}\.)?)?((w{2,3}\.)?)twitter\.[a-z]{2,3}\/?.*/i);
  var instagramUrlExp = new RegExp(/^(https?:\/\/)?((w{2,3}\.)?)instagram.[a-z]{2,3}\/?.*/i);
  var linkedInExp = new RegExp(/^(https?:\/\/)?((w{2,3}\.)?)linkedin\.[a-z]{2,3}\/?.*/i);
  var facebookCheck = facebookUrl == '' ? true : facebookUrl.match(facebookExp) ? true : false;

  if (!facebookCheck) {
    displayErrorMessage('Please enter a valid Facebook Url');
    return false;
  }

  var twitterCheck = twitterUrl == '' ? true : twitterUrl.match(twitterExp) ? true : false;

  if (!twitterCheck) {
    displayErrorMessage('Please enter a valid Twitter Url');
    return false;
  }

  var instagramCheck = instagramUrl == '' ? true : instagramUrl.match(instagramUrlExp) ? true : false;

  if (!instagramCheck) {
    displayErrorMessage('Please enter a valid Instagram Url');
    return false;
  }

  var linkedInCheck = linkedInUrl == '' ? true : linkedInUrl.match(linkedInExp) ? true : false;

  if (!linkedInCheck) {
    displayErrorMessage('Please enter a valid Linkedin Url');
    return false;
  }

  $('#createSetting')[0].submit();
  return true;
});
$(document).on('change', '.status', function (event) {
  var moduleId = $(event.currentTarget).data('id');
  updateStatus(moduleId);
});

window.updateStatus = function (id) {
  $.ajax({
    url: moduleUrl + '/' + id + '/active-deactive',
    method: 'post',
    cache: false,
    success: function success(result) {
      if (result.success) {
        setTimeout(function () {
          window.location.reload();
        }, 5000);
        displaySuccessMessage(result.message);
        tbl.ajax.reload(null, false);
      }
    }
  });
};

window.isValidLogo = function (inputSelector, validationMessageSelector) {
  var ext = $(inputSelector).val().split('.').pop().toLowerCase();

  if ($.inArray(ext, ['jpg', 'png', 'jpeg']) == -1) {
    $(inputSelector).val('');
    $(validationMessageSelector).removeClass('d-none');
    $(validationMessageSelector).html('The image must be a file of type: jpg, jpeg, png.').show();
    return false;
  }

  $(validationMessageSelector).hide();
  return true;
};

window.displayLogo = function (input, selector) {
  var displayPreview = true;

  if (input.files && input.files[0]) {
    var reader = new FileReader();

    reader.onload = function (e) {
      var image = new Image();
      image.src = e.target.result;

      image.onload = function () {
        if (image.height != 60 && image.width != 90) {
          $(selector).val('');
          $('#validationErrorsBox').removeClass('d-none');
          $('#validationErrorsBox').html(imageValidation).show();
          return false;
        }

        $(selector).attr('src', e.target.result);
        displayPreview = true;
      };
    };

    if (displayPreview) {
      reader.readAsDataURL(input.files[0]);
      $(selector).show();
    }
  }
};

$(document).on('click', '#resetFilter', function () {
  $('#filter_status').val('2').trigger('change');
});
/******/ })()
;